@@ -57,9 +57,7 @@ class PatchRepositoryIBreadCrumbsAdapter(ibreadcrumbs.IBreadCrumbsAdapter):
 
     def parent_entity(self):
         sourcerepo = self.entity.patchrepo_of
-        if sourcerepo.reverse_source_repository:
-            return sourcerepo.reverse_source_repository[0]
-        return sourcerepo
+        return sourcerepo.project or sourcerepo
 
 
 class HasPatchFacet(facet.HasRelationFacet):
